@@ -162,17 +162,26 @@ if csvOUjson == 1:
     
     arqOudir = int(input("\n Digite 3 para selecionar o arquivo CSV a ser convertido. \n Digite 4 para selecionar diretorio com arquivos CSVs a serem convertidos\n\n OPÇÃO: "))
     
-    if arqOudir == 3:
-        rota = input("Informe o caminho e o nome do arquivo CSV a ser convertido.\n Ex: tests/input/arquivo.csv \n Caminho:")
-        input_path = filter(Path.is_file, Path().rglob(f"{rota}"))
-        #log.info("Arquivo Selecionado: %s", arqOudir == 3)
-    if arqOudir == 4:
-        rota = input("Informe o caminho para acesso aos arquivos CSVs: \n Ex: TESTE/INPUT \n Caminho:")
-        input_path = filter(Path.is_file, Path().rglob(f"{rota}/*.csv"))
-        #log.info("Diretorio Selecionado: %s", arqOudir == 4)
     if arqOudir < 3 or arqOudir > 4:
         raise TypeError("Opção Invalida - Por favor repita a operação")
-        log.info("Erro: Opção Invalida arquivo ou diretorio %s", arqOudir)
+        
+
+    if arqOudir == 3:        
+        #input_path = Path(input("Informe o caminho e o nome do arquivo CSV a ser convertido.\n Ex: tests/input/arquivo.csv \n Caminho:"))
+        #print(input_path)
+        rota = input("Informe o local onde está seu arquivo CSV a ser convertido. \n Ex: /TESTS/INPUT \n Caminho: ")
+        narquivo = input("Informe o nome do arquivo. Ex: arquivo.csv \n Nome do arquivo: ")
+        input_path = filter(Path.is_file, Path(rota).rglob(f"{narquivo}"))
+    
+    
+    if arqOudir == 4:
+        rota = input("Informe o local onde estão seus arquivos CSV a ser convertido. \n Ex: /TESTS/INPUT \n Caminho: ")
+        input_path = filter(Path.is_file, Path(rota).rglob(f"*.csv"))
+        #rota = input("Informe o caminho para acesso aos arquivos CSVs: \n Ex: TESTE/INPUT \n Caminho:")
+        #input_path = filter(Path.is_file, Path().rglob(f"{rota}/*.csv"))
+        #log.info("Diretorio Selecionado: %s", arqOudir == 4)
+    
+    
 
 
     for csv in input_path:
@@ -207,13 +216,21 @@ elif csvOUjson == 2:
     arqOudir = int(input("\n Digite 3 para selecionar o arquivo JSON a ser convertido. \n Digite 4 para selecionar diretorio com arquivos JSON a serem convertidos\n OPÇÃO: "))
     
     if arqOudir == 3:
-        rota = input("Informe o caminho e o nome do arquivo JSON a ser convertido.\n Ex: tests/input/arquivo.json. \n Caminho:")
-        input_path = filter(Path.is_file, Path().rglob(f"{rota}"))
+
+        rota = input("Informe o local onde está seu arquivo JSON a ser convertido. \n Ex: /TESTS/INPUT \n Caminho: ")
+        narquivo = input("Informe o nome do arquivo JSON. Ex: arquivo.JSON \n Nome do arquivo: ")
+        input_path = filter(Path.is_file, Path(rota).rglob(f"{narquivo}"))
+        #rota = Path(input("Informe o caminho e o nome do arquivo JSON a ser convertido.\n Ex: tests/input/arquivo.json. \n Caminho:"))
+        #input_path = filter(rota.is_file)
+        
         #log.info("input_path: %s", input_path)
     if arqOudir == 4:
-        rota = input("Informe o caminho para acesso aos arquivos JSON: \n Ex: TESTE/INPUT \n Caminho:")
-        input_path = filter(Path.is_file, Path().rglob(f"{rota}/*.JSON"))
+        rota = input("Informe o local onde estão seus arquivos JSON a ser convertido. \n Ex: /TESTS/INPUT \n Caminho: ")
+        input_path = filter(Path.is_file, Path(rota).rglob(f"*.json"))
+        #rota = input("Informe o caminho para acesso aos arquivos JSON: \n Ex: TESTE/INPUT \n Caminho:")
+        #input_path = filter(Path.is_file, Path().rglob(f"{rota}/*.JSON"))
         #log.info("input_path: %s", input_path)
+    
     if arqOudir < 3 or arqOudir > 4:
         raise TypeError("Opção Invalida - Por favor repita a operação")
         log.info("erro opção invalida: %s",arqOudir)
